@@ -50,11 +50,6 @@ CLIENT = 'sentry.client.base.SentryClient'
 
 NAME = socket.gethostname()
 
-INSTALLED_APPS = (
-    'sentry',
-    'sentry.client'
-)
-
 # We allow setting the site name either by explicitly setting it with the
 # SENTRY_SITE setting, or using the django.contrib.sites framework for
 # fetching the current site. Since we can't reliably query the database
@@ -84,6 +79,8 @@ INTERNAL_IPS = set()
 
 SERVER_EMAIL = 'root@localhost'
 
+LOGIN_URL = None
+
 ## The following settings refer to the built-in webserver
 
 WEB_HOST = 'localhost'
