@@ -1,6 +1,7 @@
 from sentry.conf.defaults import *
 
 from django.conf import settings
+from django.core.urlresolvers import resolve
 from django.utils.hashcompat import md5_constructor
 from django.utils.translation import ugettext_lazy as _
 
@@ -25,6 +26,14 @@ if REMOTE_URL:
     elif not isinstance(REMOTE_URL, (list, tuple)):
         raise ValueError("Sentry setting 'REMOTE_URL' must be of type list.")
 
+# if LOGIN_URL resolves force login_required to it instead of our own
+try:
+    resolve(settings.LOGIN_URL)
+except:
+    pass
+else:
+    LOGIN_URL = settings.LOGIN_URL
+
 def configure(**kwargs):
     for k, v in kwargs.iteritems():
         if k.upper() != k:
